@@ -3,7 +3,7 @@
 ;;; Copyright © 2019, 2020, 2021, 2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
 ;;; Copyright © 2019, 2020 Rob Wieringa <rma.wieringa@gmail.com>
 ;;; Copyright © 2019, 2020, 2021, 2022 Rutger van Beusekom <rutger@dezyne.org>
-;;; Copyright © 2021 Paul Hoogendijk <paul@dezyne.org>
+;;; Copyright © 2021, 2023 Paul Hoogendijk <paul@dezyne.org>
 ;;; Copyright © 2019 Johri van Eerd <vaneerd.johri@gmail.com>
 ;;;
 ;;; This file is part of Dezyne.
@@ -32,17 +32,13 @@
   #:use-module (srfi srfi-71)
 
   #:use-module (ice-9 match)
-  #:use-module (ice-9 curried-definitions)
 
   #:use-module (dzn ast accessor)
-  #:use-module (dzn ast display)
   #:use-module (dzn ast goops)
   #:use-module (dzn ast silence)
   #:use-module (dzn ast util)
   #:use-module (dzn ast)
-  #:use-module (dzn command-line)
   #:use-module (dzn misc)
-  #:use-module (dzn parse)
   #:export (parse-tree->ast))
 
 (define* (parse-tree->ast o #:key string (file-name "<stdin>") working-directory)
@@ -620,7 +616,7 @@ to the AST element."
          (let* ((right (helper expression))
                 (zero (make <literal-node> #:value 0))
                 (left (clone zero #:location (.location right))))
-          (make <minus-node> #:left left #:right right)))
+           (make <minus-node> #:left left #:right right)))
         (('not expression) (make <not-node> #:expression (helper expression)))
 
         (('literal "true") (make <literal-node> #:value "true"))
@@ -637,6 +633,8 @@ to the AST element."
 
     (define (tree->expression o)
       (match o
+        ((left0 "-" (left1 "-" right1)) (make <minus-node> #:left (make <minus-node> #:left (helper left0) #:right (helper left1)) #:right (helper right1)))
+        ((left0 "-" (left1 "+" right1)) (make <plus-node>  #:left (make <minus-node> #:left (helper left0) #:right (helper left1)) #:right (helper right1)))
         ((left "||" right) (make <or-node> #:left (helper left) #:right (helper right)))
         ((left "&&" right) (make <and-node> #:left (helper left) #:right (helper right)))
         ((left "+" right) (make <plus-node> #:left (helper left) #:right (helper right)))
@@ -671,7 +669,7 @@ to the AST element."
 (define-method (annotate-functions (o <behavior-node>))
   (let* ((o (set-recursive (make <behavior> #:node o)))
          (o (set-noisy o)))
-   (.node o)))
+    (.node o)))
 
 (define-method (make-namespaces (o <ast>))
   o)
