@@ -1,6 +1,6 @@
 ;;; Dezyne --- Dezyne command line tools
 ;;;
-;;; Copyright © 2017, 2018, 2019, 2020, 2021, 2022, 2023 Janneke Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2017, 2018, 2019, 2020, 2021, 2022, 2023 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
 ;;; Copyright © 2018 Rob Wieringa <rma.wieringa@gmail.com>
 ;;; Copyright © 2022, 2023 Rutger (regtur) van Beusekom <rutger@dezyne.org>
 ;;;
@@ -34,15 +34,9 @@
   #:use-module (ice-9 getopt-long)
   #:use-module (ice-9 match)
   #:use-module (ice-9 poe)
-  #:use-module (system repl error-handling)
-  #:use-module (srfi srfi-1)
-  #:use-module (srfi srfi-26)
 
-  #:use-module ((oop goops) #:renamer (lambda (x) (if (member x '(<port> <foreign>)) (symbol-append 'goops: x) x)))
-
-  #:use-module (dzn config)
+  #:use-module (dzn ast goops)
   #:use-module (dzn command-line)
-  #:use-module (dzn goops)
   #:use-module (dzn misc)
   #:use-module (dzn shell-util)
   #:use-module (dzn timing)
@@ -159,7 +153,7 @@ Use \"dzn COMMAND --help\" for command-specific information.
                 (if verbose? (string-join
                               (map string.doc->string transformations)
                               "\n" 'prefix)
-                  "Use dzn --help --verbose to list transformations.")))
+                    "Use dzn --help --verbose to list transformations.")))
       (exit (or (and usage? EXIT_OTHER_FAILURE) EXIT_SUCCESS)))
     options))
 
