@@ -32,13 +32,12 @@
   #:use-module (dzn ast goops)
   #:use-module (dzn ast)
   #:use-module (dzn command-line)
+  #:use-module (dzn config)
   #:use-module (dzn explore)
   #:use-module (dzn misc)
   #:use-module (dzn parse)
   #:use-module (dzn shell-util)
-  #:use-module (dzn vm ast)
   #:use-module (dzn vm compliance)
-  #:use-module (dzn vm evaluate)
   #:use-module (dzn vm goops)
   #:use-module (dzn vm normalize)
   #:use-module (dzn vm report)
@@ -718,14 +717,14 @@ status."
                        trace))
                (port-index
                 (list-index
-                       (conjoin
-                        (compose (is? <runtime:port>) .instance)
-                        (compose (is? <initial-compound>) .statement))
-                       trace)))
+                 (conjoin
+                  (compose (is? <runtime:port>) .instance)
+                  (compose (is? <initial-compound>) .statement))
+                 trace)))
           (if (not port-index) (values trace '())
-               ;; PORT-INDEX: port <initial-compound>
-               ;; PORT-INDEX+1: port rtc
-               ;; PORT-INDEX+2: EOT or start of continuation
+              ;; PORT-INDEX: port <initial-compound>
+              ;; PORT-INDEX+1: port rtc
+              ;; PORT-INDEX+2: EOT or start of continuation
               (let ((port-index (min (+ port-index 2) (length trace))))
                 (split-at trace port-index))))))
 
@@ -870,12 +869,13 @@ status."
                  pcs)))
 
 (define* (filter-root root #:key model-name)
-  (let* ((model (ast:get-model root model-name))
-         (models (ast:model* model))
-         (root (tree-filter (disjoin (is? <interface>)
-                                     (negate (is? <model>))
-                                     (cute member <> models ast:eq?)) root)))
-    root))
+  (let ((model (ast:get-model root model-name)))
+    (if (not model) root
+        (let* ((models (ast:model* model))
+               (root (tree-filter (disjoin (is? <interface>)
+                                           (negate (is? <model>))
+                                           (cute member <> models ast:eq?)) root)))
+          root))))
 
 
 ;;;
@@ -916,8 +916,11 @@ status."
                    #:key compliance-check? deadlock-check?
                    interface-determinism-check? interface-livelock-check?
                    queue-full-check? refusals-check?
-                   model-name queue-size strict? trace trail
-                   internal? locations? state? verbose?)
+                   model-name
+                   (queue-size (%queue-size))
+                   (queue-size-defer (%queue-size-defer))
+                   (queue-size-external (%queue-size-external))
+                   strict? trace trail internal? locations? state? verbose?)
   "Entry-point for the command module: dzn simulate: start simulate
 session for MODEL, following TRAIL.  If STRICT?, the trail must include
 all observable events.  If COMPLIANCE-CHECK?, report compliance errors.
@@ -944,6 +947,8 @@ refusals-check at EOT."
                #:refusals-check? refusals-check?
                #:model-name model-name
                #:queue-size queue-size
+               #:queue-size-defer queue-size-defer
+               #:queue-size-external queue-size-external
                #:strict? strict?
                #:trace trace
                #:internal? internal?
@@ -954,9 +959,11 @@ refusals-check at EOT."
 (define* (simulate* root trail
                     #:key compliance-check? deadlock-check?
                     interface-determinism-check? interface-livelock-check?
-                    queue-full-check? refusals-check?
-                    model-name queue-size strict? trace
-                    internal? locations? state? verbose?)
+                    (queue-size (%queue-size))
+                    (queue-size-defer (%queue-size-defer))
+                    (queue-size-external (%queue-size-external))
+                    queue-full-check? refusals-check? model-name
+                    strict? trace internal? locations? state? verbose?)
   "Entry point for simulate library: start simulate session for MODEL,
 following TRAIL.  If STRICT?, the trail must include all observable
 events.  If COMPLIANCE-CHECK?, report compliance errors.  If
@@ -964,10 +971,15 @@ DEADLOCK-CHECK?, run check-deadlock at EOT.  If QUEUE-FULL-CHECK?, run
 external queue-full-check at EOT.  If REFUSALS-CHECK?, run
 refusals-check at EOT."
   (let* ((root (filter-root root #:model-name model-name))
-         (root (vm:normalize root)))
+         (root (vm:normalize root))
+         (model (ast:get-model root model-name)))
     (when (> (dzn:debugity) 1)
       (ast:pretty-print root (current-error-port)))
-    (let* ((sut (runtime:get-sut root (ast:get-model root model-name)))
+    (unless model
+      (let ((file-name (ast:source-file root)))
+        (format (current-error-port) "~a: No dezyne model found.\n" file-name))
+      (exit EXIT_OTHER_FAILURE))
+    (let* ((sut (runtime:get-sut root model))
            (instances (runtime:create-instances sut)))
       (parameterize ((%debug? (> (dzn:debugity) 0)))
         (simulate** sut instances trail
@@ -976,8 +988,10 @@ refusals-check at EOT."
                     #:interface-determinism-check? interface-determinism-check?
                     #:interface-livelock-check? interface-livelock-check?
                     #:queue-full-check? queue-full-check?
-                    #:refusals-check? refusals-check?
                     #:queue-size queue-size
+                    #:queue-size-defer queue-size-defer
+                    #:queue-size-external queue-size-external
+                    #:refusals-check? refusals-check?
                     #:strict? strict?
                     #:trace trace
                     #:internal? internal?
@@ -988,15 +1002,19 @@ refusals-check at EOT."
 (define* (simulate** sut instances trail
                      #:key compliance-check? deadlock-check?
                      interface-determinism-check? interface-livelock-check?
+                     (queue-size (%queue-size))
+                     (queue-size-defer (%queue-size-defer))
+                     (queue-size-external (%queue-size-external))
                      queue-full-check? refusals-check?
-                     queue-size strict? trace
-                     internal? locations? state? verbose?)
+                     strict? trace internal? locations? state? verbose?)
   "Entry point for simulate library, much like simulate*.  This
 procedure allows reuse with the same root, SUT and INSTANCES, allowing
 memoizations to work."
   (parameterize ((%compliance-check? compliance-check?)
                  (%instances instances)
-                 (%queue-size (or queue-size 3))
+                 (%queue-size queue-size)
+                 (%queue-size-defer queue-size-defer)
+                 (%queue-size-external queue-size-external)
                  (%strict? strict?)
                  (%sut sut))
     (run-trail trail
