@@ -1,8 +1,8 @@
 ;;; Dezyne --- Dezyne command line tools
 ;;;
-;;; Copyright © 2018, 2019, 2020, 2021, 2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2018, 2019, 2020, 2021, 2022, 2023 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
 ;;; Copyright © 2018, 2019 Rob Wieringa <rma.wieringa@gmail.com>
-;;; Copyright © 2020, 2021, 2022 Rutger van Beusekom <rutger@dezyne.org>
+;;; Copyright © 2020, 2021, 2022, 2023 Rutger van Beusekom <rutger@dezyne.org>
 ;;;
 ;;; This file is part of Dezyne.
 ;;;
@@ -27,25 +27,24 @@
   #:use-module (srfi srfi-1)
   #:use-module (srfi srfi-26)
   #:use-module (srfi srfi-71)
+
   #:use-module (ice-9 match)
   #:use-module (ice-9 rdelim)
-  #:use-module ((oop goops) #:renamer (lambda (x) (if (member x '(<port> <foreign>)) (symbol-append 'goops: x) x)))
-  #:use-module (dzn goops)
-  #:use-module (dzn command-line)
+
+  #:use-module (dzn ast goops)
   #:use-module (dzn ast)
   #:use-module (dzn code dzn)
   #:use-module (dzn misc)
-  #:use-module (dzn wfc)
   #:use-module (dzn trace)
   #:use-module (dzn vm ast)
   #:use-module (dzn vm goops)
   #:use-module (dzn vm runtime)
   #:use-module (dzn vm util)
+  #:use-module (dzn ast wfc)
   #:export (%modeling?
             debug:lts->alist
             display-trace-n
             display-trails
-            label->string
             set-trigger-locations
             trace-equal?
             trace->trail
@@ -86,11 +85,11 @@
 (define (trace-equal? a b)
   (let ((pc-a (car a))
         (pc-b (car b)))
-   (and (rtc-program-counter-equal? pc-a pc-b)
-        (ast:eq? (and=> (.previous pc-a) .statement)
-                 (and=> (.previous pc-b) .statement))
-        (equal? (trace->string-trail a)
-                (trace->string-trail b)))))
+    (and (rtc-program-counter-equal? pc-a pc-b)
+         (ast:eq? (and=> (.previous pc-a) .statement)
+                  (and=> (.previous pc-b) .statement))
+         (equal? (trace->string-trail a)
+                 (trace->string-trail b)))))
 
 (define (debug:lts->alist pc->state-number lts)
   (define (entry->pair from pc+traces)
@@ -125,7 +124,9 @@
     (or (and (eq? o (%sut))
              (not modeling?))
         (and (%modeling?)
-             modeling?))))
+             modeling?)
+        (and (is-a? (.container o) <runtime:foreign>)
+             (runtime:boundary-port? (runtime:other-port o))))))
 
 (define-method (pc-event? (o <runtime:component>) (trigger <trigger>))
   (let ((port (.port trigger)))
@@ -143,12 +144,11 @@
            (not (ast:external? o)))))
 
 (define-method (pc-event? (o <runtime:component>) (action <action>))
-  (and (not (ast:async? action))
-       (let* ((port (.port action))
-              (r:port (runtime:port o port))
-              (r:other-port (runtime:other-port r:port)))
-         (or (ast:injected? port)
-             (runtime:boundary-port? r:other-port)))))
+  (let* ((port (.port action))
+         (r:port (runtime:port o port))
+         (r:other-port (runtime:other-port r:port)))
+    (or (ast:injected? port)
+        (runtime:boundary-port? r:other-port))))
 
 (define-method (pc-event? (o <runtime:component>) (q-out <q-out>))
   (let* ((trigger (.trigger q-out))
@@ -168,12 +168,11 @@
 (define-method (pc-event? (o <runtime:component>) (return <trigger-return>))
   (let ((port (.port return)))
     (and port
-         (not (ast:async? port))
          (let* ((r:port (runtime:port o port))
                 (r:other-port (and r:port (runtime:other-port r:port))))
            (or (eq? r:port r:other-port) ;The other port is injected, no
-                                         ;chance to find our way back
-                                         ;and use ast:injected?
+                                        ;chance to find our way back
+                                        ;and use ast:injected?
                (and r:other-port
                     (runtime:boundary-port? r:other-port)
                     (ast:provides? r:other-port)))))))
@@ -186,6 +185,11 @@
 (define-method (trace-name (o <runtime:instance>))
   (cond ((is-a? (%sut) <runtime:port>) #f)
         ((null? (runtime:instance->path o)) "sut")
+        ((and (is-a? o <runtime:port>)
+              (is-a? (.container o) <runtime:foreign>)
+              (runtime:boundary-port?
+               (runtime:other-port o)))
+         (.name (.ast (runtime:other-port o))))
         (else (string-join (runtime:instance->path o) "."))))
 
 (define-method (pc->event (o <program-counter>))
@@ -214,7 +218,7 @@
   (cons trigger
         (if (is-a? (%sut) <runtime:port>)
             (format #f "~a" (.event.name trigger))
-            (format #f "~a.~a" (.name (.ast o)) (.event.name trigger)))))
+            (format #f "~a.~a" (trace-name o) (.event.name trigger)))))
 
 (define-method (pc->event (o <runtime:component>) (compound <initial-compound>) (trigger <trigger>))
   (cons trigger
@@ -266,8 +270,8 @@
           (let* ((r:port (runtime:port o port))
                  (r:other-port (and r:port (runtime:other-port r:port))))
             (if (eq? r:port r:other-port) ;The other port is injected,
-                                          ;no chance to find our way back
-                                          ;and use ast:injected?
+                                        ;no chance to find our way back
+                                        ;and use ast:injected?
                 (format #f "~a.~a" (trace-name r:port) (.event.name return))
                 (let ((value (.event.name return)))
                   (format #f "~a.~a" (trace-name r:other-port) value)))))))
@@ -320,7 +324,7 @@
                 (ast:external? o)))))
 
 (define-method (pc-arrow? (o <runtime:component>) (action <action>))
-  (not (ast:async? (.port action))))
+  #t)
 
 (define-method (pc-arrow? (o <runtime:component>) (action <defer-qout>))
   #t)
@@ -336,7 +340,7 @@
        (pc-arrow? (.instance pc) o)))
 
 (define-method (pc-arrow? (o <runtime:port>) (return <trigger-return>))
-  (let ((on (parent return <on>)))
+  (let ((on (ast:parent return <on>)))
     (and on
          (let ((trigger (car (ast:trigger* on))))
            (or (is-a? (%sut) <runtime:port>)
@@ -679,14 +683,14 @@ Add (synthesize) missing PCs for <q-in>, <q-out> and <trigger-return>."
                                  (r:other-port (runtime:other-port r:port)))
                             (or (ast:requires? r:other-port)
                                 (eq? r:port r:other-port))))) ; injected
-                 (not (ast:modeling? (car (ast:trigger* (parent statement <on>))))))
+                 (not (ast:modeling? (car (ast:trigger* (ast:parent statement <on>))))))
             (let* ((next-statement (.statement next)) ;; XXX statement *after* action
                    (next-instance (.instance next))
                    (port (.port statement))
                    (r:port (if (is-a? pc-instance <runtime:port>) pc-instance
                                (runtime:port pc-instance port)))
                    (r:other-port (runtime:other-port r:port))
-                   (interface (if port (.type port) (parent statement <interface>)))
+                   (interface (if port (.type port) (ast:parent statement <interface>)))
                    (component (.type (.ast next-instance)))
                    (port-name (if (or (not r:other-port) (eq? r:port r:other-port)) (injected-port-name component interface)
                                   (.name (.ast r:other-port))))
@@ -707,10 +711,10 @@ the location of the executed <on>-statement."
     (if (null? trace) '()
         (let* ((pc (car trace))
                (trigger (.trigger pc))
-               (model (and trigger (parent trigger <model>)))
+               (model (and trigger (ast:parent trigger <model>)))
                (on (and=> (find (conjoin (compose (is? <on>) .statement)
                                          (compose (cute ast:eq? <> model)
-                                                  (cute parent <> <model>)
+                                                  (cute ast:parent <> <model>)
                                                   .statement))
                                 trace)
                           .statement))
@@ -749,28 +753,6 @@ intermediate steps such as assignments, function calls, replies,
            (newline)))))
     (for-each write-step steps (iota (length steps)))))
 
-(define (label->string o)
-  (match o
-    (($ <action>)
-     (trigger->string o))
-    (($ <enum-literal>)
-     (string-append (ast:name (.type.name o)) ":" (.field o)))
-    (($ <literal>)
-     (label->string (.value o)))
-    ((? (is? <trigger>))
-     (trigger->string o))
-    (($ <trigger-return>)
-     (let ((prefix (or (and=> (.port.name o) (cute string-append <> ".")) "")))
-       (string-append prefix (label->string (.event.name o)))))
-    ((? (is? <model>))
-     #f)
-    ((? string?)
-     o)
-    (#f
-     "false")
-    (#t
-     "true")))
-
 (define (initial-error-message traces)
   (let* ((pcs (map car traces))
          (status (.status (car pcs))))
@@ -800,9 +782,14 @@ intermediate steps such as assignments, function calls, replies,
                                 (or (and=> (.ast (.status pc)) location-prefix)
                                     (location-prefix ast)))
                               pcs))
-              (message (if (is-a? (parent ast <model>) <component>)
-                           "component is non-deterministic due to overlapping guards"
-                           "interface is unobservably non-deterministic")))
+              (model (ast:parent ast <model>))
+              (message (if (is-a? model <component>)
+                           (simple-format
+                            #f "component ~s is non-deterministic"
+                            (ast:dotted-name model))
+                           (simple-format
+                            #f "interface ~s is unobservably non-deterministic"
+                            (ast:dotted-name model)))))
          (string-join
           (map (cut format #f "~aerror: ~a\n" <> message) locations) "")))
       (($ <queue-full-error>)
@@ -958,20 +945,6 @@ intermediate steps such as assignments, function calls, replies,
               (format #f "~ainfo: end of trail; stopping here: ~a~a\n" location prefix ast))))
       (_ #f))))
 
-(define (end-of-trail-labels pc)
-  (let* ((status (.status pc))
-         (instance (.instance pc))
-         (ast (.ast status))
-         (port-name (if instance (string-join (runtime:instance->path instance) ".")
-                        (.port.name ast)))
-         (location (location-prefix (.ast status)))
-         (ast (trigger->string (clone ast #:port.name #f)))
-         (labels (ast:label* status))
-         (labels (map label->string labels))
-         (labels (if (is-a? (%sut) <runtime:port>) labels
-                     (map (cut string-append port-name "." <>) labels))))
-    labels))
-
 (define* (report traces #:key eligible (trace "event") internal? locations? state? verbose?)
   "Print any error messages and the trail of (car TRACES) in
 trace-format TRACE, given that the trail is the same for all TRACES."
@@ -1039,10 +1012,12 @@ value of the trail."
 
     (when (and (equal? trace-format "trace")
                eligible)
-      (let* ((eligible (if (and (is-a? status <end-of-trail>) (.ast status)) (end-of-trail-labels pc)
-                           eligible))
+      (let* ((end-of-trail? (and (is-a? status <end-of-trail>) (.ast status)))
+             (end-of-trail (and end-of-trail? (end-of-trail-labels pc)))
+             (eligible (if (not end-of-trail?) eligible
+                           end-of-trail))
              (labels (or (and=> pc labels) '()))
-             (labels (if (and (pair? eligible) (not (member (car eligible) labels))) eligible
+             (labels (if (pair? end-of-trail) eligible
                          labels)))
         (format #t "~s\n" (cons 'labels labels))
         (format #t "~s\n" (cons 'eligible eligible))))
