@@ -32,7 +32,6 @@ namespace dzn
   {
     public String name;
     public Meta parent;
-    public int rank;
     public List<port.Meta> requires;
     public List<Meta> children;
     public List<Action> ports_connected;
@@ -41,7 +40,6 @@ namespace dzn
     {
       this.name = name;
       this.parent = parent;
-      this.rank = 0;
       this.requires = requires;
       this.children = children;
       this.ports_connected = ports_connected;
@@ -80,15 +78,6 @@ namespace dzn
       if (m.parent == null) return m.name + p;
       return path(m.parent, m.name + p);
     }
-    public static void rank(dzn.Meta m, int r)
-    {
-      if(null != m && m.requires != null) {
-      	m.rank = Math.Max(m.rank, r);
-	foreach (var i in m.requires) {
-	  MetaHelper.rank(i.provides.meta, m.rank + 1);
-	}
-      }
-    }
   }
 
   public class binding_error : Exception
@@ -98,26 +87,4 @@ namespace dzn
                                                  m.provides.component != null ? m.provides.name : m.requires.name) + "." + msg)
     {}
   }
-
-  public class async_base : dzn.Port {}
-  public class async<Signature>: async_base
-  {
-    public class In
-    {
-      public Signature req;
-      public delegate void signature_clr ();
-      public signature_clr clr;
-    }
-    public class Out
-    {
-      public Signature ack;
-    }
-    public In inport;
-    public Out outport;
-    public async ()
-    {
-      inport = new In ();
-      outport = new Out ();
-    }
-  }
 }
